import { showAlertFromLocalStorage } from '~/lib/utils/local_storage_alert';
import { initProjectRunnerShow } from '~/ci/runner/project_runner_show';

showAlertFromLocalStorage();
initProjectRunnerShow();
